@@ -713,9 +713,21 @@ class AllocationPolicy(proto.Message):
 
         Attributes:
             network (str):
-                The URL of the network resource.
+                The URL of an existing network resource.
+                You can specify the network as a full or partial
+                URL. For example, the following are all valid
+                URLs:
+                https://www.googleapis.com/compute/v1/projects/{project}/global/networks/{network}
+                projects/{project}/global/networks/{network}
+                global/networks/{network}
             subnetwork (str):
-                The URL of the Subnetwork resource.
+                The URL of an existing subnetwork resource in
+                the network. You can specify the subnetwork as a
+                full or partial URL. For example, the following
+                are all valid URLs:
+                https://www.googleapis.com/compute/v1/projects/{project}/regions/{region}/subnetworks/{subnetwork}
+                projects/{project}/regions/{region}/subnetworks/{subnetwork}
+                regions/{region}/subnetworks/{subnetwork}
             no_external_ip_address (bool):
                 Default is false (with an external IP
                 address). Required if no external public IP
